@@ -31,8 +31,9 @@ from cmdbot.decorators import direct
 class Line(object):
     "IRC line"
     def __init__(self, nick, message, direct=False):
-        self.nick_from = str(nick)
-        self.message = str(message.lower())
+        self.nick_from = nick
+        self._raw_message = message
+        self.message = message.lower()
         self.verb = ''
         if self.message:
             self.verb = self.message.split()[0]
@@ -66,11 +67,20 @@ class Bot(object):
         self.brain = self.Brain()  # this brain can contain *anything* you want.
 
         self.available_functions = []
+        self.no_verb_functions = []
+        self.no_help_functions = []
         for name in dir(self):
             func = getattr(self, name)
-            if callable(func) and name.startswith('do_'):
-                self.available_functions.append(name.replace('do_', ''))
-
+            if callable(func):
+                if name.startswith('do_'):
+                    self.available_functions.append(name.replace('do_', ''))
+                if hasattr(func, 'no_verb'):
+                    self.no_verb_functions.append(func)
+                if hasattr(func, "no_help"):
+                    self.no_help_functions.append(func)
+                    # little trick. helps finding out if function is decorated
+                    self.no_help_functions.append(name.replace('do_', ''))
+        logging.debug(self.no_help_functions)
         self.s = socket.socket()
 
     def connect(self):
@@ -107,15 +117,24 @@ class Bot(object):
         # actually return the Line object
         return Line(nick_from, message, direct)
 
+    def process_noverb(self, line):
+        """Process the no-verb lines
+        (i.e. a line with a first verb unreferenced in the do_<verb> methods."""
+        for func in self.no_verb_functions:
+            func(line)
+
     def process_line(self, line):
         "Process the Line object"
         func = None
         try:
-            func = getattr(self, 'do_' + line.verb)
+            func = getattr(self, 'do_%s' % line.verb)
+        except UnicodeEncodeError:
+            pass  # Do nothing, it won't work.
         except AttributeError:
             if line.direct:
                 # it's an instruction, we didn't get it.
                 self.say(_("%(nick)s: I have no clue...") % {'nick': line.nick_from})
+            self.process_noverb(line)
         if func:
             return func(line)
 
@@ -137,11 +156,13 @@ class Bot(object):
         splitted = line.message.split()
         if len(splitted) == 1:
             self.say(_('Available commands: %(commands)s')
-                % {'commands': ', '.join(self.available_functions)})
+                % {'commands': ', '.join(func for func in self.available_functions if func not in self.no_help_functions)})
         else:
             command_name = splitted[1]
             try:
                 func = getattr(self, 'do_%s' % command_name)
+                if func in self.no_help_functions:
+                    raise AttributeError
                 self.say('%s: %s' % (command_name, func.__doc__))
             except AttributeError:
                 self.say(_('Sorry, command "%(command)s" unknown')
