@@ -29,3 +29,16 @@ def contains(string):
                 return func(bot, line)
         return newfunc
     return real_decorator
+
+
+def no_verb(func):
+    """Decorator: define a function that will be executed if no verb is found
+    in the line"""
+    func.no_verb = True
+    return func
+
+
+def no_help(func):
+    """Decorator: define a function that will never display its help if asked"""
+    func.no_help = True
+    return func
